.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth documentation master file, created by
   sphinx-quickstart on Sun Feb  5 12:18:05 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###############################
TotalDepth
###############################

TotalDepth is an Open Source, cross platform, software collection that processes petrophysical data from the oil field such as wireline logs, seismic data and so on.

If you are new here then have a look at some :ref:`TotalDepth-examples`. For more detail see :ref:`TotalDepth-intro`.

The `TotalDepth project <https://github.com/paulross/TotalDepth>`_ is currently at **Alpha** version |version|, release |release|. For the licence see :ref:`licence_text`.

*******************************
Contents
*******************************

.. toctree::
	:maxdepth: 2
	
	intro
	examples/examples
	installation
	file_formats
	cmd_line_tools/index_cmd_line_tools
	usage
	tech/index_tech
	testing/index_test
	ref/index_ref
	TODO
	glossary
	licence
	
	authors
	contributing
	history
	readme

For many year this project was hosted by `Sourceforge <https://sourceforge.net/projects/TotalDepth/>`_. Thank you Sourceforge!

*******************************
Indices and tables
*******************************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

